@@ -489,7 +489,7 @@ class Stroke_intersections(object):
     """Count the number of intersections the symbol has.
 
     =======   ======= ======= ======= ===
-              stroke1 stroke2 stroke3
+      -       stroke1 stroke2 stroke3
     -------   ------- ------- ------- ---
     stroke1     0        1      0     ...
     stroke2     1        2      0     ...
